summaryrefslogtreecommitdiff
path: root/hal/phy/maximus/test/src/test_phy_ctrl.c
diff options
context:
space:
mode:
Diffstat (limited to 'hal/phy/maximus/test/src/test_phy_ctrl.c')
-rw-r--r--hal/phy/maximus/test/src/test_phy_ctrl.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/hal/phy/maximus/test/src/test_phy_ctrl.c b/hal/phy/maximus/test/src/test_phy_ctrl.c
index 1858094e2c..887b0e784c 100644
--- a/hal/phy/maximus/test/src/test_phy_ctrl.c
+++ b/hal/phy/maximus/test/src/test_phy_ctrl.c
@@ -575,8 +575,8 @@ void maximus_phy_recv_test_case(test_t t)
// set tx id
phy_hdr.tx_id = 10;
- // set transfer mode
- ctx->pbdma.transfer_mode = true;
+ // set chandata transfer
+ ctx->pbdma.chandata_transfer = true;
// frequency noise
ctx->pbdma.first_chandata = freq_noise_chandata;
@@ -813,7 +813,7 @@ void phy_init_test_case(test_t t)
&& (&phy_access_conf_cb == ctx->control.access_conf_cb)
&& (&phy_pbdma_cb == ctx->control.pbdma_cb)
&& (&phy_deferred_cb == ctx->control.deferred_cb)
- && !ctx->pbdma.transfer_mode);
+ && !ctx->pbdma.chandata_transfer);
ctx->warning_assert = true;
} test_end;